summaryrefslogtreecommitdiff
path: root/src/glx/x11/glxcmds.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/glx/x11/glxcmds.c')
-rw-r--r--src/glx/x11/glxcmds.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/glx/x11/glxcmds.c b/src/glx/x11/glxcmds.c
index 39e5f11e43b..fbb6e7b3681 100644
--- a/src/glx/x11/glxcmds.c
+++ b/src/glx/x11/glxcmds.c
@@ -2886,10 +2886,10 @@ int __glXGetInternalVersion(void)
* 20040415 - Added support for bindContext3 and unbindContext3.
* 20040602 - Add __glXGetDrawableInfo. I though that was there
* months ago. :(
* 20050725 - Gut all the old interfaces. This breaks compatability with
* any DRI driver built to any previous version.
*/
- return 20050725;
+ return 20050727;
}
@@ -2886,10 +2886,10 @@ int __glXGetInternalVersion(void)
* 20040602 - Add __glXGetDrawableInfo. I though that was there
* months ago. :(
- * 20050725 - Gut all the old interfaces. This breaks compatability with
+ * 20050727 - Gut all the old interfaces. This breaks compatability with
* any DRI driver built to any previous version.
*/